OiRA - Évaluation interactive des risques en ligne

# Prise de véhicule

Des risques peuvent apparaitre lors de la prise du véhicule par le conducteur, qui peuvent être liés au véhicule même

1. Préparation
2. Identification
   1. 1 Prise de véhicule
      1. 1.1 Connaître les équipements spécifiques du véhicule
      2. 1.2 Faire le tour du véhicule
      3. 1.3 Circuler autour du véhicule
   2. 2 Attelage
   3. 3 Mise à quai
   4. 4 Chargement / déchargement
   5. 5 Arrimage
   6. 6 Départ du quai
   7. 7 Conduite - Circulation routière
   8. 8 Arrivée chez le client
   9. 9 Maintenance de 1er niveau
   10. 10 Activités administratives
3. Estimation
4. Plan d'action
5. Rapport

Produit par EU-OSHA. | À propos | Confidentialité | Décharge de responsabilité | Licence GPL |